Module blaxel.core.client.models.preview_token_spec
===================================================

Classes
-------

`PreviewTokenSpec(expired: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, expires_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, token: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Spec for a Preview Token
    
    Attributes:
        expired (Union[Unset, bool]): Whether the token is expired
        expires_at (Union[Unset, str]): Expiration time of the token
        token (Union[Unset, str]): Token
    
    Method generated by attrs for class PreviewTokenSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `expired: blaxel.core.client.types.Unset | bool`
    :

    `expires_at: blaxel.core.client.types.Unset | str`
    :

    `token: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :